require 'dns_monkey'

describe DNSMonkey do
  subject { DNSMonkey.new(resolver: resolver) }

  let(:resolver) { Resolv::DNS.new }

  it 'responds to #a_record_name' do
    expect(subject).to respond_to(:a_record_name)
  end

  describe '#a_record_name' do

    let(:non_existent_record_name) { 'non-existent.dns-monkey.knowitnot.com' }
    let(:a_record_name) { 'my-a-record.dns-monkey.knowitnot.com' }
    let(:cname_record_name) { 'my-cname-record.dns-monkey.knowitnot.com' }
    let(:other_cname_record_name) { 'my-other-cname-record.dns-monkey.knowitnot.com' }

    it 'returns name of A record, when passed an A record name' do
      expect(subject.a_record_name(a_record_name)).to eq(a_record_name)
    end

    it 'returns name of A record, when passed a CNAME record name' do
      expect(subject.a_record_name(cname_record_name)).to eq(a_record_name)
      expect(subject.a_record_name(other_cname_record_name)).to eq(a_record_name)
    end

    it 'returns nil when passed a non-existent record name' do
      expect(subject.a_record_name(non_existent_record_name)).to be nil
    end
  end
end
